@@ -5,6 +5,8 @@ my(%status) = (
    inc => "Loaded Modules",
    rgysubs => "Compiled Registry Scripts",
    symdump => "Symbol Table Dump",
+   inh_tree => "Inheritance Tree",
+   isa_tree => "ISA Tree",	       
 );
 
 sub menu_item {
@@ -99,6 +101,9 @@ sub status_rgysubs {
     \@retval;
 }
 
+sub status_inh_tree { ["<pre>", Devel::Symdump->inh_tree, "</pre>"] }
+sub status_isa_tree { ["<pre>", Devel::Symdump->isa_tree, "</pre>"] }
+
 1;
 
 __END__
@@ -107,6 +112,13 @@ __END__
 
 Apache::Status - Embedded interpreter status information 
 
+=head1 SYNOPSIS
+
+ <Location /perl-status>
+ SetHandler  perl-script
+ PerlHandler Apache::Status
+ </Location>
+
 =head1 DESCRIPTION
 
 The B<Apache::Status> module provides some information
